@@ -1,67 +1,70 @@
 var languageNames = {
 "en-US": "angleški (ZDA)",
+"sq": "albanski",
 "am": "amharski",
 "ar": "arabski",
 "ast": "asturijski",
-"bg": "bolgarski",
 "bn": "bengalski",
 "bn-IN": "bengalski (Indija)",
-"bo": "tibetanski",
 "bs": "bosanski",
+"bg": "bolgarski",
 "ca": "katalonski",
 "ca-valencia": "katalonski (valencijski)",
+"zh-CN": "kitajski (poenostavljeni)",
+"zh-TW": "kitajski (tradicionalni)",
+"hr": "hrvaški",
 "cs": "češki",
 "da": "danski",
-"de": "nemški",
+"nl": "nizozemski",
 "dz": "džonkški",
-"el": "grški",
 "en-GB": "angleški (Združeno kraljestvo)",
 "en-ZA": "angleški (Južna Afrika)",
 "eo": "esperanto",
-"es": "španski",
 "et": "estonski",
 "eu": "baskovski",
 "fi": "finski",
 "fr": "francoski",
 "gl": "galicijski",
+"ka": "gruzijski",
+"de": "nemški",
+"el": "grški",
 "gu": "gudžaratski",
 "he": "hebrejski",
 "hi": "hindujski",
-"hr": "hrvaški",
 "hu": "madžarski",
 "id": "indonezijski",
 "is": "islandski",
 "it": "italijanski",
 "ja": "japonski",
-"ka": "gruzijski",
 "km": "kmerski",
 "ko": "korejski",
 "lo": "laoški",
-"lt": "litovski",
 "lv": "latvijski",
+"lt": "litovski",
 "mk": "makedonski",
-"nb": "norveški (bokmal)",
 "ne": "nepalski",
-"nl": "nizozemski",
 "nn": "norveški (ninorsk)",
+"nb": "norveški (bokmal)",
 "om": "oromski",
 "pl": "poljski",
 "pt": "portugalski",
 "pt-BR": "portugalski (Brazilija)",
 "ro": "romunski",
 "ru": "ruski",
-"si": "sinhalski",
 "sid": "sidamski",
+"si": "sinhalski",
 "sk": "slovaški",
 "sl": "slovenski",
-"sq": "albanski",
+"dsb": "lužiško srbski, dolnji",
+"hsb": "lužiško srbski, gornji",
+"es": "španski",
 "sv": "švedski",
-"ta": "tamilski",
 "tg": "tadžiški",
+"ta": "tamilski",
+"bo": "tibetanski",
+"tl": "Tagalog",
 "tr": "turški",
 "ug": "ujgurski",
 "uk": "ukrajinski",
 "vi": "vietnamski",
-"zh-CN": "kitajski (poenostavljeni)",
-"zh-TW": "kitajski (tradicionalni)",
 };
